<!--
Description of PR
-->

<!--
Checklist for for pull requests including new code and/or changes to existing code...
-->

* [ ] Includes unit tests
* [ ] New functions have docstrings with examples that can be run with doctest
* [ ] New functions are included in API docs
* [ ] Docstrings include notes for any changes to API or behaviour
* [ ] Travis CI passes (unit tests run under Linux)
* [ ] AppVeyor CI passes (unit tests run under Windows)
* [ ] Unit test coverage has not decreased (see Coveralls)
* [ ] All changes documented in docs/changes.rst
